Documentation
¶
Index ¶
- Constants
- func DecodeDiagnosticEvents(events string) ([]xdr.DiagnosticEvent, error)
- func DiagnosticEventsToSlice(events string) ([]string, error)
- type GetLedgerEntryRawResponse
- type GetLedgerEntryResponse
- type InfoResponse
- type LedgerEntryResponse
- type LedgerInfo
- type PreflightResponse
- type RawLedgerEntryResponse
- type TXResponse
Constants ¶
const ( // Indicates that the entry is live in the current state LedgerEntryStateLive = "live" // Indicates that the entry wasn't found (thus proven to be brand new) and // will live in the current state if created. LedgerEntryStateNotFound = "not-found" // Indicates that the entry has been archived to the hot archive due to its // TTL expiring LedgerEntryStateArchived = "archived" )
const ( // PreflightStatusError represents the status value returned by stellar-core when an error occurred from // processing a preflight request PreflightStatusError = "ERROR" // PreflightStatusOk represents the status value returned by stellar-core when a preflight request // succeeded PreflightStatusOk = "OK" )
const ( // TXStatusError represents the status value returned by stellar-core when an error occurred from // submitting a transaction TXStatusError = "ERROR" // TXStatusPending represents the status value returned by stellar-core when a transaction has // been accepted for processing TXStatusPending = "PENDING" // TXStatusDuplicate represents the status value returned by stellar-core when a submitted // transaction is a duplicate TXStatusDuplicate = "DUPLICATE" // TXStatusTryAgainLater represents the status value returned by stellar-core when a submitted // transaction was not included in the previous 4 ledgers and get banned for being added in the // next few ledgers. TXStatusTryAgainLater = "TRY_AGAIN_LATER" )
Variables ¶
This section is empty.
Functions ¶
func DecodeDiagnosticEvents ¶
func DecodeDiagnosticEvents(events string) ([]xdr.DiagnosticEvent, error)
DecodeDiagnosticEvents returns the decoded events
func DiagnosticEventsToSlice ¶
DiagnosticEventsToSlice transforms the base64 diagnostic events into a slice of individual base64-encoded diagnostic events
Types ¶
type GetLedgerEntryRawResponse ¶
type GetLedgerEntryRawResponse struct {
Ledger uint32 `json:"ledger"`
Entries []RawLedgerEntryResponse `json:"entries"`
}
GetLedgerEntryRawResponse is the structure of Stellar Core's /getledgerentryraw
type GetLedgerEntryResponse ¶
type GetLedgerEntryResponse struct {
Ledger uint32 `json:"ledgerSeq"`
Entries []LedgerEntryResponse `json:"entries"`
}
GetLedgerEntryResponse is the structure of Stellar Core's /getledgerentry
type InfoResponse ¶
type InfoResponse struct {
Info struct {
Build string `json:"build"`
Network string `json:"network"`
ProtocolVersion int `json:"protocol_version"`
State string `json:"state"`
Ledger LedgerInfo `json:"ledger"`
}
}
InfoResponse is the json response returned from stellar-core's /info endpoint.
func (*InfoResponse) IsSynced ¶
func (resp *InfoResponse) IsSynced() bool
IsSynced returns a boolean indicating whether stellarcore is synced with the network.
type LedgerEntryResponse ¶
type LedgerInfo ¶
type LedgerInfo struct {
Age int `json:"age"`
BaseFee int `json:"baseFee"`
BaseReserve int `json:"baseReserve"`
CloseTime int `json:"closeTime"`
Hash string `json:"hash"`
MaxTxSetSize int `json:"maxTxSetSize"`
Num int `json:"num"`
Version int `json:"version"`
}
LedgerInfo is the part of the stellar-core's info json response. It's returned under `ledger` key
type PreflightResponse ¶
type PreflightResponse struct {
Status string `json:"status"`
Detail string `json:"detail"`
Result string `json:"result"`
Footprint string `json:"footprint"`
CPUInstructions uint64 `json:"cpu_insns"`
MemoryBytes uint64 `json:"mem_bytes"`
Ledger int64 `json:"ledger"`
}
PreflightResponse is the response from Stellar Core for the preflight endpoint
type RawLedgerEntryResponse ¶
type RawLedgerEntryResponse struct {
Entry string `json:"le"` // base64-encoded xdr.LedgerEntry
}
type TXResponse ¶
type TXResponse struct {
Exception string `json:"exception"`
Error string `json:"error"`
Status string `json:"status"`
// DiagnosticEvents is an optional base64-encoded XDR Variable-Length Array of DiagnosticEvents
DiagnosticEvents string `json:"diagnostic_events,omitempty"`
}
TXResponse represents the response returned from a submission request sent to stellar-core's /tx endpoint
func (*TXResponse) IsException ¶
func (resp *TXResponse) IsException() bool
IsException returns true if the response represents an exception response from stellar-core